import aiohttp


async def aioget(url, params={}, timeout=10):
    async with aiohttp.ClientSession() as session:
        response = await session.get(url, params=params, timeout=timeout)
        return await response.text()



from bs4 import BeautifulSoup

from .aioget import aioget


async def search(query):
    results = []
    page = await aioget(f"https://memepedia.ru", {"s": query})
    soup = BeautifulSoup(page, "lxml")

    ul = soup.find("ul", {"class": "post-items"})
    
    for li in ul.find_all("li"):
        article = li.find("article")
        content = article.find_all("div", {"class": "content"})[0]

        results.append({
            "title": content.header.h2.a.text,
            "name": content.header.h2.a["href"][21:-1]
        })

    return results



from bs4 import BeautifulSoup
from tghtml import tghtml

from .aioget import aioget


async def page(name):
    text = await aioget(f"https://memepedia.ru/{name}/")
    parsed = tghtml(text, [
        ["section"],
        ["ul"], ["ol"], ["li"],
        ["div", {"class": "mistape_caption"}]
    ])

    soup = BeautifulSoup(text, "lxml")

    try:
        image = soup.find_all("figure", {"class": "s-post-media-img"})[0].img["src"]
    except IndexError:
        image = ""

    return [image, parsed.replace("•", "")]
